@@ -5,11 +5,11 @@ import (
 	"fmt"
 	"net/http"
 
-	"gitlab.com/gitlab-org/cli/internal/commands/mr/mrutils"
+	"github.com/spf13/cobra"
 
 	"gitlab.com/gitlab-org/cli/internal/cmdutils"
-
-	"github.com/spf13/cobra"
+	"gitlab.com/gitlab-org/cli/internal/commands/mr/mrutils"
+	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
 )
 
 var errTodoExists = errors.New("To-do already exists.")
@@ -21,6 +21,9 @@ func NewCmdTodo(f cmdutils.Factory) *cobra.Command {
 		Short:   "Add a to-do item to merge request.",
 		Long:    ``,
 		Args:    cobra.MaximumNArgs(1),
+		Annotations: map[string]string{
+			mcpannotations.Destructive: "true",
+		},
 		RunE: func(cmd *cobra.Command, args []string) error {
 			var err error
 			c := f.IO().Color()
@@ -30,7 +33,7 @@ func NewCmdTodo(f cmdutils.Factory) *cobra.Command {
 				return err
 			}
 
-			mr, repo, err := mrutils.MRFromArgs(f, args, "any")
+			mr, repo, err := mrutils.MRFromArgs(cmd.Context(), f, args, "any")
 			if err != nil {
 				return err
 			}
